yatr
====

.. image:: https://travis-ci.org/mbodenhamer/yatr.svg?branch=master
    :target: https://travis-ci.org/mbodenhamer/yatr
    
.. image:: https://img.shields.io/coveralls/mbodenhamer/yatr.svg
    :target: https://coveralls.io/r/mbodenhamer/yatr

.. image:: https://readthedocs.org/projects/yatr/badge/?version=latest
    :target: http://yatr.readthedocs.org/en/latest/?badge=latest

Yet Another Task Runner.  Or alternatively, YAml Task Runner.  Yatr is a YAML-based task runner designed for 21st-century software-development contexts.  The project is in the preliminary stages of development, but is nonetheless functional for a number of applications.

To install, run::

    $ pip install yatr


More information can be found in the `package documentation`_.

.. _package documentation: http://yatr.readthedocs.org/en/latest/
